@@ -46,7 +46,10 @@ class Domoticz(IPlugin):
 			if rs['ids'] == idex :
 #				log.msg("index trouvé :  ***")
 				bodies == rs['boy']
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
+				log.msg("BODIES  :  %s" % (bodies))
+				log.msg("on off  :  %s" % (on_off))
+				log.msg("number  :  %s" % (rs['idx']))	
+				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off))
 				log.msg("resp  :  %s" % (resp))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
